# Generated by Django 2.2 on 2023-02-10 14:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0009_auto_20230210_1430'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Template',
            new_name='FormTemplate',
        ),
        migrations.RenameModel(
            old_name='TemplateItem',
            new_name='FormTemplateItem',
        ),
    ]
