{% extends base %}
{% load date_extras %}

{% block content %}

{% include "components/banners.html" %}

{% if plot_today %}
    <div style="margin-top:20px; display: flex; justify-content: center;">
    <a href="{{plot_today}}">
    <img src="{{plot_today}}" width="512px"/>
    </a>
    </div>
{% endif %}

{% if plot %}
    <div style="margin-top:20px; display: flex; justify-content: center;">
    <a href="{{plot}}">
    <img src="{{plot}}" width="512px"/>
    </a>
    </div>
{% endif %}

{% endblock %}